@@ -15,14 +15,17 @@ register('create', command_create, 'Create restfx project structure', 'project-n
 register('genid', command_genid, 'Generate a new id for app')
 
 
-def execute(argv=None):
-    args = (argv or sys.argv)[1:]
+def execute(*args, **kwargs):
+    args = list((args or sys.argv)[1:])
 
-    working_dir = os.path.abspath(os.path.curdir)
+    if 'working_dir' in kwargs:
+        working_dir = kwargs['working_dir']
+    else:
+        working_dir = os.path.abspath(os.path.curdir)
 
     if len(args) == 0:
-        run_command(working_dir, 'help')
-        return
+        return False
+        # return run_command(working_dir, 'help')
 
     command_name = args.pop(0)
-    run_command(working_dir, command_name, *args)
+    return run_command(working_dir, command_name, *args)
