@@ -2,6 +2,7 @@ import os
 
 from ..config import AppConfig
 from ..http import BadRequest, HttpResponse, JsonResponse, NotFound
+from ..util import utils
 from ..util.func_util import FunctionDescription
 
 
@@ -43,10 +44,14 @@ class ApiPage:
         if request.method != 'GET':
             return NotFound()
         if not self.api_page_html_cache or not self.config.api_page_cache:
+            from restfx import __meta__
             with open(os.path.join(os.path.dirname(__file__),
                                    '../internal_assets/templates/api_page.html'),
                       encoding='utf-8') as fp:
-                lines = fp.readlines()
+                lines = [
+                    line.replace('{{version}}', __meta__.version)
+                    for line in fp.readlines()
+                ]
                 self.api_page_html_cache = ''.join(lines)
                 fp.close()
         return HttpResponse(self.api_page_html_cache, content_type='text/html')
@@ -66,6 +71,10 @@ class ApiPage:
             'name': self.config.api_page_name,
             'expanded': self.config.api_page_expanded,
             'routes': self.routes_cache,
+            'enums': [
+                utils.get_enum_items(item)
+                for item in self.config.enum_types
+            ],
             'custom_assets': self.config.api_page_assets
         }, encoder=FunctionDescription.JSONEncoder, ensure_ascii=request.GET.get('ascii') == 'true')
 
